@@ -12,17 +12,13 @@ from .configuration import PlotmanConfig, get_db_path
 
 
 def PostDat(dp: dict, cfg: PlotmanConfig):
-    try:
-        # sending post request and saving response as response object
-        payload = json.dumps(dp)
-        r = requests.post(url=f'{cfg.apis.target}:{cfg.apis.port}/report', data=payload)
-        print(r.text)
-    except ValueError as e:
-        print('got ValueError from io', e)
+    # sending post request and saving response as response object
+    payload = json.dumps(dp)
+    requests.post(url=f'http://{cfg.apis.target}:{cfg.apis.port}/report', data=payload)
+
 
 """
 
-
 from prometheus_client.core import GaugeMetricFamily
 
 class PlotmanCollector:
@@ -33,8 +29,6 @@ class PlotmanCollector:
         count = len(sorted(jobs, key=job.Job.get_time_wall))
         yield GaugeMetricFamily("plotman_jobs_count", "Number of plotting jobs running", value=count)
 
-
-
 if __name__ == "__main__":
     start_http_server(8001)
     REGISTRY.register(PlotmanCollector())
